@@ -68,7 +68,6 @@ def old_fn_deprecation(opt):
                           "and will be removed in a future release.\n"
                           "Use of default filenames is strongly suggested.") % opt
 
-
 def expand_fn(filename):
     return os.path.expanduser(os.path.expandvars(filename))
 
@@ -145,6 +144,7 @@ def check_verbosity(option, opt, value):
 
     return verb
 
+
 class DupOption(optparse.Option):
     TYPES = optparse.Option.TYPES + ("file", "time", "verbosity",)
     TYPE_CHECKER = copy(optparse.Option.TYPE_CHECKER)
@@ -169,6 +169,34 @@ class DupOption(optparse.Option):
             optparse.Option.take_action(
                 self, action, dest, opt, value, values, parser)
 
+"""
+Fix:
+    File "/usr/lib/pythonX.X/optparse.py", line XXXX, in print_help
+    file.write(self.format_help().encode(encoding, "replace"))
+    UnicodeDecodeError: 'ascii' codec can't decode byte 0xXX in position XXXX:
+See:
+    http://bugs.python.org/issue2931
+    http://mail.python.org/pipermail/python-dev/2006-May/065458.html
+"""
+class OPHelpFix(optparse.OptionParser):
+    def _get_encoding(self, file):
+        """
+        try to get the encoding or use UTF-8
+        which is default encoding in python3 and most recent unixes
+        """
+        encoding = getattr(file, "encoding", None)
+        return encoding or 'utf-8'
+
+    def print_help(self, file=None):
+        """
+        overwrite method with proper utf-8 decoding
+        """
+        if file is None:
+            file = sys.stdout
+        encoding = self._get_encoding(file)
+        file.write(self.format_help().decode('utf-8').encode(encoding, "replace"))
+
+
 def parse_cmdline_options(arglist):
     """Parse argument list"""
     global select_opts, select_files, full_backup
@@ -179,7 +207,7 @@ def parse_cmdline_options(arglist):
             import duplicity.backends.giobackend
             backend.force_backend(duplicity.backends.giobackend.GIOBackend)
         except ImportError:
-            log.FatalError(_("Unable to load gio module"), log.ErrorCode.gio_not_available)
+            log.FatalError(_("Unable to load gio backend: %s") % str(sys.exc_info()[1]), log.ErrorCode.gio_not_available)
 
     def set_log_fd(fd):
         if fd < 1:
@@ -211,7 +239,7 @@ def parse_cmdline_options(arglist):
     def add_rename(o, s, v, p):
         globals.rename[os.path.normcase(os.path.normpath(v[0]))] = v[1]
 
-    parser = optparse.OptionParser(option_class=DupOption, usage=usage())
+    parser = OPHelpFix( option_class=DupOption, usage=usage() )
 
     # If this is true, only warn and don't raise fatal error when backup
     # source directory doesn't match previous backup source directory.
@@ -248,7 +276,7 @@ def parse_cmdline_options(arglist):
 
     # secret keyring in which the private encrypt key can be found
     parser.add_option("--encrypt-secret-keyring", type="string", metavar=_("path"))
-    
+
     parser.add_option("--encrypt-sign-key", type="string", metavar=_("gpg-key-id"),
                       dest="", action="callback",
                       callback=lambda o, s, v, p: ( globals.gpg_profile.recipients.append(v), set_sign_key(v)) )
@@ -292,6 +320,13 @@ def parse_cmdline_options(arglist):
     parser.add_option("--fail-on-volume", type="int",
                       help=optparse.SUPPRESS_HELP)
 
+    # used to provide a prefix on top of the defaul tar file name
+    parser.add_option("--file-prefix", type="string", dest="file_prefix", action="store")
+
+    # used in testing only - skips upload for a given volume
+    parser.add_option("--skip-volume", type="int",
+                      help=optparse.SUPPRESS_HELP)
+
     # If set, restore only the subdirectory or file specified, not the
     # whole root.
     # TRANSL: Used in usage help to represent a Unix-style path name. Example:
@@ -315,6 +350,12 @@ def parse_cmdline_options(arglist):
 
     parser.add_option("--gpg-options", action="extend", metavar=_("options"))
 
+    # TRANSL: Used in usage help to represent an ID for a hidden GnuPG key. Example:
+    # --hidden-encrypt-key <gpg_key_id>
+    parser.add_option("--hidden-encrypt-key", type="string", metavar=_("gpg-key-id"),
+                      dest="", action="callback",
+                      callback=lambda o, s, v, p: globals.gpg_profile.hidden_recipients.append(v)) #@UndefinedVariable
+
     # ignore (some) errors during operations; supposed to make it more
     # likely that you are able to restore data under problematic
     # circumstances. the default should absolutely always be False unless
@@ -365,6 +406,9 @@ def parse_cmdline_options(arglist):
     # If set to false, then do not encrypt files on remote system
     parser.add_option("--no-encryption", action="store_false", dest="encryption")
 
+    # If set to false, then do not compress files on remote system
+    parser.add_option("--no-compression", action="store_false", dest="compression")
+
     # If set, print the statistics after every backup session
     parser.add_option("--no-print-statistics", action="store_false", dest="print_statistics")
 
@@ -401,6 +445,9 @@ def parse_cmdline_options(arglist):
     # duplicity remove-older-than time [options] target_url
     parser.add_option("--restore-time", "--time", "-t", type="time", metavar=_("time"))
 
+    # user added rsync options
+    parser.add_option("--rsync-options", action="extend", metavar=_("options"))
+
     # Whether to create European buckets (sorry, hard-coded to only
     # support european for now).
     parser.add_option("--s3-european-buckets", action="store_true")
@@ -417,12 +464,21 @@ def parse_cmdline_options(arglist):
     # See <https://bugs.launchpad.net/duplicity/+bug/433970>.
     parser.add_option("--s3-unencrypted-connection", action="store_true")
 
-    # scp command to use
-    # TRANSL: noun
+    # Chunk size used for S3 multipart uploads.The number of parallel uploads to
+    # S3 be given by chunk size / volume size. Use this to maximize the use of
+    # your bandwidth. Defaults to 25MB
+    parser.add_option("--s3-multipart-chunk-size", type="int", action="callback", metavar=_("number"),
+                      callback=lambda o, s, v, p: setattr(p.values, "s3_multipart_chunk_size", v*1024*1024))
+
+    # Option to allow the s3/boto backend use the multiprocessing version.
+    # By default it is off since it does not work for Python 2.4 or 2.5.
+    if sys.version_info[:2] >= (2,6):
+        parser.add_option("--s3-use-multiprocessing", action="store_true")
+
+    # scp command to use (ssh pexpect backend)
     parser.add_option("--scp-command", metavar=_("command"))
 
-    # sftp command to use
-    # TRANSL: noun
+    # sftp command to use (ssh pexpect backend)
     parser.add_option("--sftp-command", metavar=_("command"))
 
     # If set, use short (< 30 char) filenames for all the remote files.
@@ -440,9 +496,17 @@ def parse_cmdline_options(arglist):
     # default to batch mode using public-key encryption
     parser.add_option("--ssh-askpass", action="store_true")
 
+    # allow the user to switch ssh backend
+    parser.add_option("--ssh-backend", metavar=_("paramiko|pexpect"))
+
     # user added ssh options
     parser.add_option("--ssh-options", action="extend", metavar=_("options"))
 
+    # user added ssl options (webdav backend)
+    parser.add_option("--ssl-cacert-file", metavar=_("pem formatted bundle of certificate authorities"))
+
+    parser.add_option("--ssl-no-check-certificate", action="store_true")
+
     # Working directory for the tempfile module. Defaults to /tmp on most systems.
     parser.add_option("--tempdir", dest="temproot", type="file", metavar=_("path"))
 
@@ -477,6 +541,7 @@ def parse_cmdline_options(arglist):
     parser.add_option("--volsize", type="int", action="callback", metavar=_("number"),
                       callback=lambda o, s, v, p: setattr(p.values, "volsize", v*1024*1024))
 
+    # parse the options
     (options, args) = parser.parse_args()
 
     # Copy all arguments and their values to the globals module.  Don't copy
@@ -804,6 +869,7 @@ def set_selection():
     sel.ParseArgs(select_opts, select_files)
     globals.select = sel.set_iter()
 
+
 def args_to_path_backend(arg1, arg2):
     """
     Given exactly two arguments, arg1 and arg2, figure out which one
@@ -827,6 +893,7 @@ page for more information.""")
     else:
         raise AssertionError('should not be reached')
 
+
 def set_backend(arg1, arg2):
     """Figure out which arg is url, set backend
 
