@@ -24,7 +24,10 @@
 import socket, os
 
 # The current version of duplicity
-version = "0.6.10"
+version = "0.6.21"
+
+# Default file_prefix value
+file_prefix = ""
 
 # The name of the current host, or None if it cannot be set
 hostname = socket.getfqdn()
@@ -36,6 +39,9 @@ local_path = None
 # The symbolic name of the backup being operated upon.
 backup_name = None
 
+# For testing -- set current time
+current_time = None
+
 # Set to the Path of the archive directory (the directory which
 # contains the signatures and manifests of the relevent backup
 # collection), and for checkpoint state between volumes.
@@ -76,6 +82,9 @@ null_separator = None
 # number of retries on network operations
 num_retries = 5
 
+# True if Pydev debugger should be activated
+pydevd = False
+
 # Character used like the ":" in time strings like
 # 2002-08-06T04:22:00-07:00.  The colon isn't good for filenames on
 # windows machines.
@@ -99,8 +108,7 @@ short_filenames = False
 # the time specified
 full_force_time = None
 
-# Used to confirm certain destructive operations like deleting old
-# files.
+# Used to confirm certain destructive operations like deleting old files.
 force = None
 
 # If set, signifies time in seconds before which backup files should
@@ -123,6 +131,9 @@ dry_run = False
 # If set to false, then do not encrypt files on remote system
 encryption = True
 
+# If set to false, then do not compress files on remote system
+compression = True
+
 # volume size. default 25M
 volsize = 25*1024*1024
 
@@ -151,9 +162,27 @@ s3_use_new_style = False
 # support european for now).
 s3_european_buckets = False
 
+# File owner uid keeps number from tar file. Like same option in GNU tar.
+numeric_owner = False
+
+# Whether to use plain HTTP (without SSL) to send data to S3
+# See <https://bugs.launchpad.net/duplicity/+bug/433970>.
+s3_unencrypted_connection = False
+
 # Whether to use S3 Reduced Redudancy Storage
 s3_use_rrs = False
 
+# True if we should use boto multiprocessing version
+s3_use_multiprocessing = False
+
+# Chunk size used for S3 multipart uploads.The number of parallel uploads to
+# S3 be given by chunk size / volume size. Use this to maximize the use of
+# your bandwidth. Defaults to 25MB
+s3_multipart_chunk_size = 25*1024*1024
+
+# Minimum chunk size accepted by S3
+s3_multipart_minimum_chunk_size = 5*1024*1024
+
 # Whether to use the full email address as the user name when
 # logging into an imap server. If false just the user name
 # part of the email address is used.
@@ -169,25 +198,38 @@ old_filenames = False
 # Wheter to specify --use-agent in GnuPG options
 use_agent = False
 
-# ssh commands to use
-scp_command = "scp"
-sftp_command = "sftp"
+# ssh commands to use, used by ssh_pexpect (defaults to sftp, scp)
+scp_command = None
+sftp_command = None
 
 # default to batch mode using public-key encryption
 ssh_askpass = False
 
+# default ssh backend is paramiko
+ssh_backend = "paramiko"
+
 # user added ssh options
 ssh_options = ""
 
 # whether to use scp for put/get, sftp is default
 use_scp = False
 
+# HTTPS ssl optons (currently only webdav)
+ssl_cacert_file = None
+ssl_no_check_certificate = False
+
+# user added rsync options
+rsync_options = ""
+
 # will be a Restart object if restarting
 restart = None
 
 # used in testing only - raises exception after volume
 fail_on_volume = 0
 
+# used in testing only - skips uploading a particular volume
+skip_volume = 0
+
 # ignore (some) errors during operations; supposed to make it more
 # likely that you are able to restore data under problematic
 # circumstances. the default should absolutely always be True unless
