@@ -54,7 +54,7 @@ class GPGProfile:
     Just hold some GPG settings, avoid passing tons of arguments
     """
     def __init__(self, passphrase = None, sign_key = None,
-                 recipients = None):
+                 recipients = None, hidden_recipients = None):
         """
         Set all data with initializer
 
@@ -76,6 +76,12 @@ class GPGProfile:
         else:
             self.recipients = []
 
+        if hidden_recipients is not None:
+            assert type(hidden_recipients) is types.ListType # must be list, not tuple
+            self.hidden_recipients = hidden_recipients
+        else:
+            self.hidden_recipients = []
+
 
 class GPGFile:
     """
@@ -131,7 +137,10 @@ class GPGFile:
             if profile.recipients:
                 gnupg.options.recipients = profile.recipients
                 cmdlist.append('--encrypt')
-            else:
+            if profile.hidden_recipients:
+                gnupg.options.hidden_recipients = profile.hidden_recipients
+                cmdlist.append('--encrypt')
+            if not (profile.recipients or profile.hidden_recipients):
                 cmdlist.append('--symmetric')
                 # use integrity protection
                 gnupg.options.extra_args.append('--force-mdc')
@@ -149,7 +158,7 @@ class GPGFile:
                 p1.handles['passphrase'].close()
             self.gpg_input = p1.handles['stdin']
         else:
-            if profile.recipients and profile.encrypt_secring:
+            if (profile.recipients or profile.hidden_recipients) and profile.encrypt_secring:
                 cmdlist.append('--secret-keyring')
                 cmdlist.append(profile.encrypt_secring)
             self.status_fp = tempfile.TemporaryFile( dir=tempdir.default().dir() )
@@ -310,17 +319,16 @@ def GPGWriteFile(block_iter, filename, profile,
     def get_current_size():
         return os.stat(filename).st_size
 
-    block_size = 128 * 1024        # don't bother requesting blocks smaller, but also don't ask for bigger
     target_size = size - 50 * 1024 # fudge factor, compensate for gpg buffering
     data_size = target_size - max_footer_size
     file = GPGFile(True, path.Path(filename), profile)
     at_end_of_blockiter = 0
     while True:
         bytes_to_go = data_size - get_current_size()
-        if bytes_to_go < block_size:
+        if bytes_to_go < block_iter.get_read_size():
             break
         try:
-            data = block_iter.next(min(block_size, bytes_to_go)).data
+            data = block_iter.next().data
         except StopIteration:
             at_end_of_blockiter = 1
             break
@@ -369,10 +377,10 @@ def GzipWriteFile(block_iter, filename,
     at_end_of_blockiter = 0
     while True:
         bytes_to_go = size - file_counted.byte_count
-        if bytes_to_go < 32 * 1024:
+        if bytes_to_go < block_iter.get_read_size():
             break
         try:
-            new_block = block_iter.next(min(128*1024, bytes_to_go))
+            new_block = block_iter.next()
         except StopIteration:
             at_end_of_blockiter = 1
             break
