@@ -28,14 +28,15 @@ associates stat information with filenames
 
 import stat, errno, socket, time, re, gzip
 
+from duplicity import tarfile
 from duplicity import file_naming
 from duplicity import globals
 from duplicity import gpg
-from duplicity import tarfile
 from duplicity import util
 from duplicity import librsync
 from duplicity import log #@UnusedImport
 from duplicity import dup_time
+from duplicity import cached_ops
 from duplicity.lazy import * #@UnusedWildImport
 
 _copy_blocksize = 64 * 1024
@@ -147,8 +148,9 @@ class ROPath:
             return "."
 
     def getperms(self):
-        """Return permissions mode"""
-        return self.mode
+        """Return permissions mode, owner and group"""
+        s1 = self.stat
+        return '%s:%s %o' % (s1.st_uid, s1.st_gid, self.mode)
 
     def open(self, mode):
         """Return fileobj associated with self"""
@@ -197,13 +199,21 @@ class ROPath:
         self.mode = tarinfo.mode
         self.stat = StatResult()
 
-        # Set user and group id
+        """ Set user and group id 
+        use numeric id if name lookup fails
+        OR
+        --numeric-owner is set 
+        """
         try:
-            self.stat.st_uid = tarfile.uname2uid(tarinfo.uname)
+            if globals.numeric_owner:
+                raise KeyError
+            self.stat.st_uid = cached_ops.getpwnam(tarinfo.uname)[2]
         except KeyError:
             self.stat.st_uid = tarinfo.uid
         try:
-            self.stat.st_gid = tarfile.gname2gid(tarinfo.gname)
+            if globals.numeric_owner:
+                raise KeyError
+            self.stat.st_gid = cached_ops.getgrnam(tarinfo.gname)[2]
         except KeyError:
             self.stat.st_gid = tarinfo.gid
 
@@ -275,13 +285,13 @@ class ROPath:
                 ti.mtime = int(self.stat.st_mtime)
 
             try:
-                ti.uname = tarfile.uid2uname(ti.uid)
+                ti.uname = cached_ops.getpwuid(ti.uid)[0]
             except KeyError:
-                pass
+                ti.uname = ''
             try:
-                ti.gname = tarfile.gid2gname(ti.gid)
+                ti.gname = cached_ops.getgrgid(ti.gid)[0]
             except KeyError:
-                pass
+                ti.gname = ''
 
             if ti.type in (tarfile.CHRTYPE, tarfile.BLKTYPE):
                 if hasattr(os, "major") and hasattr(os, "minor"):
@@ -351,7 +361,7 @@ class ROPath:
 
         if self.isreg() or self.isdir() or self.isfifo():
             if not self.perms_equal(other):
-                log_diff(_("File %%s has permissions %o, expected %o") %
+                log_diff(_("File %%s has permissions %s, expected %s") %
                          (other.getperms(), self.getperms()))
                 return 0
             if ((int(self.stat.st_mtime) != int(other.stat.st_mtime)) and
@@ -377,7 +387,7 @@ class ROPath:
                 return 0
         elif self.isdev():
             if not self.perms_equal(other):
-                log_diff(_("File %%s has permissions %o, expected %o") %
+                log_diff(_("File %%s has permissions %s, expected %s") %
                          (other.getperms(), self.getperms()))
                 return 0
             if self.devnums != other.devnums:
@@ -418,6 +428,7 @@ class ROPath:
             os.mkdir(other.name)
         elif self.issym():
             os.symlink(self.symtext, other.name)
+            os.lchown(other.name, self.stat.st_uid, self.stat.st_gid)
             other.setdata()
             return # no need to copy symlink attributes
         elif self.isfifo():
@@ -491,7 +502,7 @@ class Path(ROPath):
             self.stat = os.lstat(self.name)
         except OSError, e:
             err_string = errno.errorcode[e[0]]
-            if err_string == "ENOENT" or err_string == "ENOTDIR" or err_string == "ELOOP":
+            if err_string in ["ENOENT", "ENOTDIR", "ELOOP", "ENOTCONN"]:
                 self.stat, self.type = None, None # file doesn't exist
                 self.mode = None
             else:
@@ -552,9 +563,9 @@ class Path(ROPath):
         """Remove this file"""
         log.Info(_("Deleting %s") % (self.name,))
         if self.isdir():
-            os.rmdir(self.name)
+            util.ignore_missing(os.rmdir, self.name)
         else:
-            os.unlink(self.name)
+            util.ignore_missing(os.unlink, self.name)
         self.setdata()
 
     def touch(self):
